package com.ichaoj.ams.script.zksync2.swap;

import cn.hutool.core.util.CharsetUtil;
import cn.hutool.core.util.HexUtil;
import cn.hutool.crypto.SecureUtil;
import cn.hutool.crypto.symmetric.SymmetricAlgorithm;
import cn.hutool.crypto.symmetric.SymmetricCrypto;
import com.ichaoj.ams.constant.AmsConstant;
import com.ichaoj.ams.script.JavaScript;
import com.ichaoj.ams.script.JsScript;
import com.ichaoj.ams.script.model.SResult;
import com.ichaoj.ams.script.model.AirdropParam;
import com.ichaoj.ams.script.model.AirdropWallet;
import org.junit.jupiter.api.Test;

import java.util.HashMap;

class ZksyncMuteSwapEthForUsdcScriptTest {
    @Test
    void swapEth() {
        JsScript script = new ZksyncSwapEthForUsdcScript();

        HashMap<String, AirdropParam> params = new HashMap<>();
        params.put("amountMin", new AirdropParam("amountMin", null, "0.0004"));
        params.put("amountMax", new AirdropParam("amountMax", null, "0.0005"));
        params.put("accuracy", new AirdropParam("amountMax", null, "5"));
        AirdropWallet airdropWallet = new AirdropWallet();
        airdropWallet.setAddress("0x368715F09C1AB5E0B55bF5bA19cD887189A28DBE");
        airdropWallet.setPrivateKey("f9eac039449802f20cf0a38bc0b6f4064508fa61897d9c4fcb6cb66bd1311674");
        SResult sResult = script.run(params, airdropWallet);
        System.out.println(sResult);
    }

    @Test
    void swapUsdc() {
        JsScript script = new ZksyncSwapUsdcForEthScript();

        HashMap<String, AirdropParam> params = new HashMap<>();
        params.put("amountMin", new AirdropParam("amountMin", null, "0.0004"));
        params.put("amountMax", new AirdropParam("amountMax", null, "0.0005"));
        params.put("accuracy", new AirdropParam("amountMax", null, "5"));
        AirdropWallet airdropWallet = new AirdropWallet();
        airdropWallet.setAddress("0x368715F09C1AB5E0B55bF5bA19cD887189A28DBE");
        airdropWallet.setPrivateKey("f9eac039449802f20cf0a38bc0b6f4064508fa61897d9c4fcb6cb66bd1311674");
        SResult sResult = script.run(params, airdropWallet);
        System.out.println(sResult);
    }


    @Test
    void hexTest() {
        AmsConstant.aesKey = HexUtil.encodeHexStr(SecureUtil.generateKey(SymmetricAlgorithm.AES.getValue()).getEncoded());
        byte[] encoded = SecureUtil.generateKey(SymmetricAlgorithm.AES.getValue()).getEncoded();
        byte[] dateByte=new byte[]{
                2,0,2,3,0,6,2,9,2,0,2,3,0,6,2,9
        };

        SymmetricCrypto aes = new SymmetricCrypto(SymmetricAlgorithm.AES, dateByte);
//        SymmetricCrypto aes = new SymmetricCrypto(SymmetricAlgorithm.AES, encoded);
        String content = "password";
        //加密为16进制表示
        String encryptHex = aes.encryptHex(content);
//解密为字符串
        String decryptStr = aes.decryptStr(encryptHex, CharsetUtil.CHARSET_UTF_8);
        System.out.println("encryptHex : " + encryptHex);
        System.out.println("decryptStr : " + decryptStr);
    }

}